#include "StdAfx.h"
#include "ToastLoggerManager.h"

ToastLogger* ToastLoggerManager::_logger = NULL;
ToastLoggerUserFields* ToastLoggerManager::_userFieldMap = CreateToastLoggerUserFields();

void ToastLoggerManager::InitializeSdk(const char* appkey,
										const char* version,
										TOAST_SERVICE_ZONE serviceZone,
										bool enableCrashReport,
										bool enableCrashSilenceMode,
										bool enableGDPRFilter,
										TOAST_LANGUAGE_TYPE langType, 
										const wchar_t* dialogMessage)
{
	// set logger configuration
	ToastLoggerConfiguration* loggerConf = GetToastLoggerConfiguration();

	loggerConf->setProjectKey(appkey);
	loggerConf->setProjectVersion(version);
	loggerConf->setServiceZone(serviceZone);
	loggerConf->enableCrashReporter(enableCrashReport);
    loggerConf->enableCrashSilenceMode(enableCrashSilenceMode);
	loggerConf->enableApplyGDPR(enableGDPRFilter);
	loggerConf->setCrashReporterMessage(langType, dialogMessage);
	loggerConf->saveCrashReporterMessageToJson();

	// logger initialize
	_logger = GetToastLogger();

	if (_logger != NULL)
	{
		_logger->initialize(loggerConf);
	}
}

void ToastLoggerManager::SendInfo(const char* message)
{
	InternalSend(LOG_LEVEL_INFO, message);
}
void ToastLoggerManager::SendDebug(const char* message)
{
	InternalSend(LOG_LEVEL_DEBUG, message);
}

void ToastLoggerManager::SendWarn(const char* message)
{
	InternalSend(LOG_LEVEL_WARN, message);
}

void ToastLoggerManager::SendError(const char* message)
{
	InternalSend(LOG_LEVEL_ERROR, message);
}

void ToastLoggerManager::SendFatal(const char* message)
{
	InternalSend(LOG_LEVEL_FATAL, message);
}

void ToastLoggerManager::InternalSend(TOAST_LOGGER_LEVEL level, const char* message)
{
	if (_userFieldMap != NULL)
	{
		if (_userFieldMap->size() > 0)
		{
			_logger->log(level, message, _userFieldMap);
		}
		else
		{
			_logger->log(level, message);
		}
	}
	else
	{
		_logger->log(level, message);
	}
}

void ToastLoggerManager::InsertUserField(const char* key, const char* value)
{
	_userFieldMap->insert(key, value);
}

bool ToastLoggerManager::FindUserField(const char* key)
{

	return _userFieldMap->find(key);
}

void ToastLoggerManager::DeleteUserField(const char* key)
{
	_userFieldMap->erase(key);
}

void ToastLoggerManager::ClearUserField()
{
	_userFieldMap->clear();
}

void ToastLoggerManager::InsertGlobalField(const char* key, const char* value)
{
	if (_logger != NULL)
	{
		_logger->addUserField(key, value);
	}
}

void ToastLoggerManager::DeleteGlobalField(const char* key)
{
	if (_logger != NULL)
	{
		_logger->removeUserField(key);
	}
}

void ToastLoggerManager::ClearGlobalField()
{
	if (_logger != NULL)
	{
		_logger->clearUserFileds();
	}
}

